@@ -1,5 +1,6 @@
 package Dancer2::Plugin::MarkdownFilesToHTML ;
-$Dancer2::Plugin::MarkdownFilesToHTML::VERSION = '0.005';
+$Dancer2::Plugin::MarkdownFilesToHTML::VERSION = '0.006';
+use 5.13.2;
 use strict;
 use warnings;
 use Dancer2::Plugin;
@@ -17,16 +18,11 @@ use Dancer2::Plugin::MarkdownFilesToHTML::MarkdownParser;
 plugin_keywords qw( mdfile_2html mdfiles_2html );
 
 # builds the routes from config file
-#
 sub BUILD {
   my $s = shift;
   my $app = $s->app;
   my $config = $s->config;
 
-  # generate the cache if it doesn't exist
-  if (!-d 'lib/data/markdown_files/cache') {
-    make_path 'lib/data/markdown_files'
-  }
 
   # add routes from config file
   my $routes = $config->{routes};
@@ -172,9 +168,11 @@ sub mdfiles_2html {
   return ($html, $toc);
 }
 
+
 # The workhorse function of this module which sends the markdown file to get
 # parsed or retrieves html version from cache. Also generates the table of
 # contents
+
 # TODO: make the TOC generation optional based on config setting
 sub mdfile_2html {
 	my $s        = shift;
@@ -190,6 +188,11 @@ sub mdfile_2html {
   # check the cache for a hit by comparing timestemps of cached file and
   # markdown file
 
+  # generate the cache if it doesn't exist
+  if (!-d 'lib/data/markdown_files/cache') {
+    make_path 'lib/data/markdown_files'
+  }
+
   my $cache_file = $file =~ s/\///gr;
   $cache_file = "lib/data/markdown_files/cache/$cache_file";
   if (-f $cache_file && $options->{cache}) {
@@ -281,7 +284,7 @@ Dancer2::Plugin::MarkdownFilesToHTML
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -530,7 +533,7 @@ create like this:
         routes:
           - another_page:
             dir: 'my_dir_containing_md_file'
-            include_files
+            include_files:
               - 'file4.md'
               - 'file2.md'
               - 'file1.md'
